# Import modules
import pandas as pd, numpy as np
import sklearn
from sklearn.model_selection import train_test_split
from sklearn import metrics
from catboost import CatBoostClassifier
import joblib

df = joblib.load('data.joblib')

# categorical variables
cats = ['earliest_cr_line', 'last_pymnt_d', 'application_type']
# features and target column
X = df.drop(['bad_loans'],1)
y = df['bad_loans']
# split into training and testing sets
X_train, X_test, y_train, y_test = train_test_split(X, y, test_size=0.2, random_state=42, stratify=y)
model = CatBoostClassifier(iterations=1005, learning_rate=0.01, cat_features=cats,
                           loss_function= 'Logloss', eval_metric='AUC',
                           use_best_model=True,random_seed=42)
model.fit(X_train, y_train, eval_set=(X_test, y_test), plot=False)
# make predictions
y_pred = model.predict(X_test)
y_probs = model.predict_proba(X_test)
# accuracy score : number of correct predictions
accuracy = metrics.accuracy_score(y_test, y_pred)
print("Accuracy: %.2f%%" % (accuracy * 100.0))
joblib.dump(model, 'model.joblib')
print("Model dumped!")

# Saving the data columns from training
model_columns = list(X.columns)
joblib.dump(model_columns, 'model_columns.joblib')
print("Models columns dumped!")
